@@ -98,7 +98,7 @@ class Controller:
     def shorteningService(self):
         url = self.url
         short_url, long_url = url, ''
-        test_read = open(r'./data/shortening_services.txt', 'r')
+        test_read = open(r'./src/data/shortening_services.txt', 'r')
         
         havingIP = Controller.havingIPAddress(self)
         
@@ -182,7 +182,7 @@ class Controller:
             if(len(issued_by.split(" "))>1):
                 CA = issued_by.split(" ")[0] + " " + issued_by.split(" ")[1] 
             
-            SSL_read = open(r'./data/ssl_list.txt','r')
+            SSL_read = open(r'./src/data/ssl_list.txt','r')
             
             if((issued_by.split()[0] or CA)in SSL_read.read()):
                 return 0
@@ -190,7 +190,7 @@ class Controller:
                 return 1
     
     def domainRegistration(self):
-        test_read = open(r'./data/edu_domains.txt', 'r')
+        test_read = open(r'./src/data/edu_domains.txt', 'r')
         parts = self.parts
         domain_name = parts.netloc
         if('.edu' in domain_name):
